==> moodle-1.4.3-mysql.tgz: moodle/lang/fr/choice.php <==
<?php // $Id$ 

$string['allowupdate'] = 'Permettre la mise  jour du sondage';
$string['answered'] = 'Rpondu';
$string['choice'] = 'Proposition $a';
$string['choiceclose'] = 'Jusqu\'au';
$string['choicename'] = 'Nom du sondage';
$string['choiceopen'] = 'Ouvert';
$string['choicetext'] = 'Texte de la question';
$string['havetologin'] = 'Vous devez vous connecter pour pouvoir rpondre  ce sondage';
$string['modulename'] = 'Sondage';
$string['modulenameplural'] = 'Sondages';
$string['mustchooseone'] = 'Vous devez slectionner une rponse avant d\'enregistrer. L\'enregistrement n\'a pas eu lieu.';
$string['notanswered'] = 'Pas encore rpondu';
$string['notopenyet'] = 'Dsol, cette activit sera disponible ds le $a';
$string['privacy'] = 'Confidentialit des rsultats';
$string['publish'] = 'Publication des rsultats';
$string['publishafteranswer'] = 'Afficher les rsultats aux tudiants aprs leur rponse';
$string['publishafterclose'] = 'N\'afficher les rsultats aux tudiants qu\'une fois le sondage ferm';
$string['publishalways'] = 'Toujours afficher les rsultats aux tudiants';
$string['publishanonymous'] = 'Publier les rsultats anonymement, sans afficher le nom des tudiants';
$string['publishnames'] = 'Publier les rsultats complets, avec le nom des tudiants et leur choix';
$string['publishnot'] = 'Ne pas publier les rsultats pour les tudiants';
$string['responses'] = 'Rponses';
$string['responsesto'] = 'Rponses  $a';
$string['savemychoice'] = 'Enregistrer mon vote';
$string['showunanswered'] = 'Afficher la colonne des  sans rponse ';
$string['timerestrict'] = 'Ne permettre les rponses que durant cette priode';
$string['viewallresponses'] = 'Voir les $a rponses';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/fr/choice.php <==
<?php // $Id$ 

$string['addmorechoices'] = 'Ajouter d\'autres propositions';
$string['allowupdate'] = 'Permettre la mise  jour du sondage';
$string['answered'] = 'Rpondu';
$string['choice'] = 'Proposition';
$string['choiceclose'] = 'Jusqu\'au';
$string['choicename'] = 'Nom du sondage';
$string['choiceopen'] = 'Ouvert le';
$string['choicetext'] = 'Texte de la question';
$string['displayhorizontal'] = 'Afficher horizontalement';
$string['displaymode'] = 'Mode d\'affichage';
$string['displayvertical'] = 'Afficher verticalement';
$string['full'] = '(complet)';
$string['havetologin'] = 'Vous devez vous connecter pour pouvoir rpondre  ce sondage';
$string['limit'] = 'Limite';
$string['limitanswers'] = 'Limiter le nombre de rponses permises';
$string['modulename'] = 'Sondage';
$string['modulenameplural'] = 'Sondages';
$string['mustchooseone'] = 'Vous devez slectionner une rponse avant d\'enregistrer. L\'enregistrement n\'a pas eu lieu.';
$string['notanswered'] = 'Pas encore rpondu';
$string['notopenyet'] = 'Dsol, cette activit sera disponible ds le $a';
$string['privacy'] = 'Confidentialit des rsultats';
$string['publish'] = 'Publication des rsultats';
$string['publishafteranswer'] = 'Afficher les rsultats aux tudiants aprs leur rponse';
$string['publishafterclose'] = 'N\'afficher les rsultats aux tudiants qu\'une fois le sondage ferm';
$string['publishalways'] = 'Toujours afficher les rsultats aux tudiants';
$string['publishanonymous'] = 'Publier les rsultats anonymement, sans afficher le nom des tudiants';
$string['publishnames'] = 'Publier les rsultats complets, avec le nom des tudiants et leur choix';
$string['publishnot'] = 'Ne pas publier les rsultats pour les tudiants';
$string['responses'] = 'Rponses';
$string['responsesto'] = 'Rponses  $a';
$string['savemychoice'] = 'Enregistrer mon vote';
$string['showunanswered'] = 'Afficher la colonne des  sans rponse ';
$string['spaceleft'] = 'espace disponible';
$string['spacesleft'] = 'espaces disponibles';
$string['taken'] = 'Effectu';
$string['timerestrict'] = 'Sondage limit dans le temps';
$string['viewallresponses'] = 'Voir les $a rponses';
$string['yourselection'] = 'Votre choix';

?>
